@@ -2,14 +2,14 @@ from sys import exit
 import os
 from os.path import join
 
+
 def no_config(f):
     f.__no_config = True
     return f
 
 
-class Target(object):
+class Target:
     def __init__(self, buildozer):
-        super(Target, self).__init__()
         self.buildozer = buildozer
         self.build_mode = 'debug'
         self.platform_update = False
