@@ -24,10 +24,9 @@ import os
 import io
 import re
 import ast
-import sh
 from pipes import quote
 from sys import platform, executable
-from buildozer import BuildozerException, USE_COLOR, IS_PY3
+from buildozer import BuildozerException, USE_COLOR
 from buildozer.target import Target
 from os import environ
 from os.path import exists, join, realpath, expanduser, basename, relpath
@@ -45,7 +44,7 @@ DEPRECATED_TOKENS = (('app', 'android.sdk'), )
 # because it doesn't seem to matter much, it is normally correct to
 # download once then update all the components as buildozer already
 # does.
-DEFAULT_SDK_TAG = '4333796'
+DEFAULT_SDK_TAG = '6514223'
 
 DEFAULT_ARCH = 'armeabi-v7a'
 
@@ -66,7 +65,7 @@ class TargetAndroid(Target):
     extra_p4a_args = ''
 
     def __init__(self, *args, **kwargs):
-        super(TargetAndroid, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self._arch = self.buildozer.config.getdefault(
             'app', 'android.arch', DEFAULT_ARCH)
         self._build_dir = join(
@@ -160,8 +159,11 @@ class TargetAndroid(Target):
     def _sdkmanager(self, *args, **kwargs):
         """Call the sdkmanager in our Android SDK with the given arguments."""
         # Use the android-sdk dir as cwd by default
-        kwargs['cwd'] = kwargs.get('cwd', self.android_sdk_dir)
-        command = self.sdkmanager_path + ' ' + ' '.join(args)
+        android_sdk_dir = self.android_sdk_dir
+        kwargs['cwd'] = kwargs.get('cwd', android_sdk_dir)
+        sdkmanager_path = self.sdkmanager_path
+        sdk_root = f"--sdk_root={android_sdk_dir}"
+        command = f"{sdkmanager_path} {sdk_root} " + ' '.join(args)
         return_child = kwargs.pop('return_child', False)
         if return_child:
             return self.buildozer.cmd_expect(command, **kwargs)
@@ -249,7 +251,7 @@ class TargetAndroid(Target):
                                                        break_on_error=False)
             is_debian_like = (returncode_dpkg == 0)
             if is_debian_like and \
-                not self.buildozer.file_exists('/usr/include/zlib.h'):
+                    not self.buildozer.file_exists('/usr/include/zlib.h'):
                 raise BuildozerException(
                     'zlib headers must be installed, '
                     'run: sudo apt-get install zlib1g-dev')
@@ -287,7 +289,7 @@ class TargetAndroid(Target):
                         '[app] "android.permission" contain an unknown'
                         ' permission {0}'.format(permission))
 
-        super(TargetAndroid, self).check_configuration_tokens(errors)
+        super().check_configuration_tokens(errors)
 
     def _get_available_permissions(self):
         key = 'android:available_permissions'
@@ -373,18 +375,18 @@ class TargetAndroid(Target):
 
         self.buildozer.info('Android SDK is missing, downloading')
         if platform in ('win32', 'cygwin'):
-            archive = 'sdk-tools-windows-{}.zip'.format(DEFAULT_SDK_TAG)
+            archive = 'commandlinetools-win-{}_latest.zip'.format(DEFAULT_SDK_TAG)
         elif platform in ('darwin', ):
-            archive = 'sdk-tools-darwin-{}.zip'.format(DEFAULT_SDK_TAG)
+            archive = 'commandlinetools-mac-{}_latest.zip'.format(DEFAULT_SDK_TAG)
         elif platform.startswith('linux'):
-            archive = 'sdk-tools-linux-{}.zip'.format(DEFAULT_SDK_TAG)
+            archive = 'commandlinetools-linux-{}_latest.zip'.format(DEFAULT_SDK_TAG)
         else:
             raise SystemError('Unsupported platform: {0}'.format(platform))
 
         if not os.path.exists(sdk_dir):
             os.makedirs(sdk_dir)
 
-        url = 'http://dl.google.com/android/repository/'
+        url = 'https://dl.google.com/android/repository/'
         self.buildozer.download(url,
                                 archive,
                                 cwd=sdk_dir)
@@ -525,8 +527,10 @@ class TargetAndroid(Target):
             # This leads to a stderr "Broken pipe" message which is harmless,
             # but doesn't look good on terminal, hence redirecting to /dev/null
             yes_command = 'yes 2>/dev/null'
-            command = '{} | {} --licenses'.format(
-                yes_command, self.sdkmanager_path)
+            android_sdk_dir = self.android_sdk_dir
+            sdkmanager_path = self.sdkmanager_path
+            sdk_root = f"--sdk_root={android_sdk_dir}"
+            command = f"{yes_command} | {sdkmanager_path} {sdk_root} --licenses"
             self.buildozer.cmd(command, cwd=self.android_sdk_dir)
         else:
             kwargs['show_output'] = True
@@ -574,7 +578,7 @@ class TargetAndroid(Target):
         if self.buildozer.state.get(cache_key, None) == cache_value:
             return True
 
-        # 1. update the tool and platform-tools if needed
+        # 1. update the platform-tools package if needed
 
         skip_upd = self.buildozer.config.getbooldefault(
             'app', 'android.skip_update', False)
@@ -583,7 +587,7 @@ class TargetAndroid(Target):
             self.buildozer.info('Installing/updating SDK platform tools if necessary')
 
             # just calling sdkmanager with the items will install them if necessary
-            self._android_update_sdk('tools', 'platform-tools')
+            self._android_update_sdk('platform-tools')
             self._android_update_sdk('--update')
         else:
             self.buildozer.info('Skipping Android SDK update due to spec file setting')
@@ -740,7 +744,7 @@ class TargetAndroid(Target):
         try:
             with open(join(self.p4a_dir, "setup.py")) as fd:
                 setup = fd.read()
-                deps = re.findall("^\s*install_reqs = (\[[^\]]*\])", setup, re.DOTALL | re.MULTILINE)[0]
+                deps = re.findall(r"^\s*install_reqs = (\[[^\]]*\])", setup, re.DOTALL | re.MULTILINE)[0]
                 deps = ast.literal_eval(deps)
         except IOError:
             self.buildozer.error('Failed to read python-for-android setup.py at {}'.format(
@@ -768,7 +772,7 @@ class TargetAndroid(Target):
             'P4A_{}_DIR'.format(name[20:]): realpath(expanduser(value))
             for name, value in self.buildozer.config.items('app')
             if name.startswith('requirements.source.')
-            }
+        }
         if source_dirs:
             self.buildozer.environ.update(source_dirs)
             self.buildozer.info('Using custom source dirs:\n    {}'.format(
@@ -917,7 +921,7 @@ class TargetAndroid(Target):
         if not entrypoint:
             self.buildozer.config.set('app', 'android.entrypoint', 'org.kivy.android.PythonActivity')
 
-        super(TargetAndroid, self).cmd_run(*args)
+        super().cmd_run(*args)
 
         entrypoint = self.buildozer.config.getdefault(
             'app', 'android.entrypoint', 'org.kivy.android.PythonActivity')
@@ -1055,12 +1059,12 @@ class TargetAndroid(Target):
             build_cmd += [('--add-compile-option', option)]
 
         # android.add_gradle_repositories
-        repos = config.getlist('app','android.add_gradle_repositories', [])
+        repos = config.getlist('app', 'android.add_gradle_repositories', [])
         for repo in repos:
             build_cmd += [('--add-gradle-repository', repo)]
 
         # android packaging options
-        pkgoptions = config.getlist('app','android.add_packaging_options', [])
+        pkgoptions = config.getlist('app', 'android.add_packaging_options', [])
         for pkgoption in pkgoptions:
             build_cmd += [('--add-packaging-option', pkgoption)]
 
@@ -1114,7 +1118,7 @@ class TargetAndroid(Target):
             build_cmd += [("--ouya-icon", join(self.buildozer.root_dir,
                                                ouya_icon))]
 
-        if config.getdefault('app','p4a.bootstrap','sdl2') != 'service_only':
+        if config.getdefault('app', 'p4a.bootstrap', 'sdl2') != 'service_only':
             # add orientation
             orientation = config.getdefault('app', 'orientation', 'landscape')
             if orientation == 'all':
@@ -1144,6 +1148,11 @@ class TargetAndroid(Target):
         if launch_mode:
             build_cmd += [("--activity-launch-mode", launch_mode)]
 
+        # numeric version
+        numeric_version = config.getdefault('app', 'android.numeric_version')
+        if numeric_version:
+            build_cmd += [("--numeric-version", numeric_version)]
+
         # build only in debug right now.
         if self.build_mode == 'debug':
             build_cmd += [("debug", )]
@@ -1312,7 +1321,7 @@ class TargetAndroid(Target):
             self.buildozer.cmd(' '.join([self.adb_cmd] + args))
 
     def cmd_deploy(self, *args):
-        super(TargetAndroid, self).cmd_deploy(*args)
+        super().cmd_deploy(*args)
         state = self.buildozer.state
         if 'android:latestapk' not in state:
             self.buildozer.error('No APK built yet. Run "debug" first.')
@@ -1360,6 +1369,7 @@ def get_target(buildozer):
     buildozer.targetname = "android"
     return TargetAndroid(buildozer)
 
+
 def generate_dist_folder_name(base_dist_name, arch_names=None):
     """Generate the distribution folder name to use, based on a
     combination of the input arguments.
